@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 #include "tokenlist.h"
 #include "utils.h"
 #include "valueptr.h"
-#include "vfvalue.h"
 
 #include <algorithm>
 #include <cassert>
@@ -47,7 +46,6 @@
 namespace {
     struct ForwardTraversal {
         enum class Progress : std::uint8_t { Continue, Break, Skip };
-        enum class Terminate : std::uint8_t { None, Bail, Inconclusive };
         ForwardTraversal(const ValuePtr<Analyzer>& analyzer, const TokenList& tokenList, ErrorLogger& errorLogger, const Settings& settings)
             : analyzer(analyzer), tokenList(tokenList), errorLogger(errorLogger), settings(settings)
         {}
@@ -112,10 +110,10 @@ namespace {
                 return std::make_pair(false, false);
             std::vector<MathLib::bigint> result = analyzer->evaluate(tok, ctx);
             // TODO: We should convert to bool
-            const bool checkThen = std::any_of(result.cbegin(), result.cend(), [](int x) {
+            const bool checkThen = std::any_of(result.cbegin(), result.cend(), [](MathLib::bigint x) {
                 return x != 0;
             });
-            const bool checkElse = std::any_of(result.cbegin(), result.cend(), [](int x) {
+            const bool checkElse = std::any_of(result.cbegin(), result.cend(), [](MathLib::bigint x) {
                 return x == 0;
             });
             return std::make_pair(checkThen, checkElse);
@@ -144,7 +142,7 @@ namespace {
                 traverseRecursive(tok->astOperand2(), f, traverseUnknown);
                 traverseRecursive(tok->astOperand1(), f, traverseUnknown);
                 return Break(Analyzer::Terminate::Escape);
-            } else if (Token::Match(tok, "%name% (") && isEscapeFunction(tok, &settings.library)) {
+            } else if (Token::Match(tok, "%name% (") && isEscapeFunction(tok, settings.library)) {
                 // Traverse the parameters of the function before escaping
                 traverseRecursive(tok->next()->astOperand2(), f, traverseUnknown);
                 return Break(Analyzer::Terminate::Escape);
@@ -203,7 +201,8 @@ namespace {
 
         template<class T, class F, REQUIRES("T must be a Token class", std::is_convertible<T*, const Token*> )>
         Progress traverseConditional(T* tok, F f, bool traverseUnknown) {
-            if (Token::Match(tok, "?|&&|%oror%") && tok->astOperand1() && tok->astOperand2()) {
+            Analyzer::Action action = analyzer->analyze(tok, Analyzer::Direction::Forward);
+            if (action.isNone() && Token::Match(tok, "?|&&|%oror%") && tok->astOperand1() && tok->astOperand2()) {
                 const T* condTok = tok->astOperand1();
                 T* childTok = tok->astOperand2();
                 bool checkThen, checkElse;
@@ -228,12 +227,19 @@ namespace {
                     if (traverseRecursive(childTok, f, traverseUnknown) == Progress::Break)
                         return Break();
                 }
+            } else {
+                return f(tok, action);
             }
             return Progress::Continue;
         }
 
         Progress update(Token* tok) {
             Analyzer::Action action = analyzer->analyze(tok, Analyzer::Direction::Forward);
+            return update(tok, action);
+        }
+
+        Progress update(Token* tok, Analyzer::Action action)
+        {
             actions |= action;
             if (!action.isNone() && !analyzeOnly)
                 analyzer->update(tok, action, Analyzer::Direction::Forward);
@@ -247,29 +253,54 @@ namespace {
             return Progress::Continue;
         }
 
+        struct AsUpdate {
+            ForwardTraversal* self = nullptr;
+
+            explicit AsUpdate(ForwardTraversal* self) : self(self) {}
+
+            template<class... Ts>
+            Progress operator()(Ts... xs) const
+            {
+                assert(self);
+                return self->update(xs ...);
+            }
+        };
+
         Progress updateTok(Token* tok, Token** out = nullptr) {
-            auto f = [this](Token* tok2) {
-                return update(tok2);
-            };
-            return traverseTok(tok, f, false, out);
+            return traverseTok(tok, AsUpdate{this}, false, out);
         }
 
         Progress updateRecursive(Token* tok) {
-            auto f = [this](Token* tok2) {
-                return update(tok2);
-            };
-            return traverseRecursive(tok, f, false);
+            return traverseRecursive(tok, AsUpdate{this}, false);
         }
 
+        struct AsAnalyze {
+            ForwardTraversal* self = nullptr;
+            Analyzer::Action* result = nullptr;
+
+            AsAnalyze(ForwardTraversal* self, Analyzer::Action* result) : self(self), result(result) {}
+
+            Progress operator()(const Token* tok) const
+            {
+                assert(self);
+                assert(result);
+                return (*this)(tok, self->analyzer->analyze(tok, Analyzer::Direction::Forward));
+            }
+
+            Progress operator()(const Token* /*unused*/, Analyzer::Action action) const
+            {
+                assert(self);
+                assert(result);
+                *result = action;
+                if (result->isModified() || result->isInconclusive())
+                    return self->Break();
+                return Progress::Continue;
+            }
+        };
+
         Analyzer::Action analyzeRecursive(const Token* start) {
             Analyzer::Action result = Analyzer::Action::None;
-            auto f = [&](const Token* tok) {
-                result = analyzer->analyze(tok, Analyzer::Direction::Forward);
-                if (result.isModified() || result.isInconclusive())
-                    return Break();
-                return Progress::Continue;
-            };
-            traverseRecursive(start, f, true);
+            traverseRecursive(start, AsAnalyze{this, &result}, true);
             return result;
         }
 
@@ -337,11 +368,6 @@ namespace {
             return r;
         }
 
-        enum class Status : std::uint8_t {
-            None,
-            Inconclusive,
-        };
-
         Analyzer::Action analyzeScope(const Token* endBlock) const {
             return analyzeRange(endBlock->link(), endBlock);
         }
@@ -613,17 +639,17 @@ namespace {
                         return Break(Analyzer::Terminate::Bail);
                 } else if (tok->link() && tok->str() == "}" && tok == tok->scope()->bodyEnd) { // might be an init list
                     const Scope* scope = tok->scope();
-                    if (contains({Scope::eDo, Scope::eFor, Scope::eWhile, Scope::eIf, Scope::eElse, Scope::eSwitch}, scope->type)) {
-                        const bool inElse = scope->type == Scope::eElse;
-                        const bool inDoWhile = scope->type == Scope::eDo;
-                        const bool inLoop = contains({Scope::eDo, Scope::eFor, Scope::eWhile}, scope->type);
+                    if (contains({ScopeType::eDo, ScopeType::eFor, ScopeType::eWhile, ScopeType::eIf, ScopeType::eElse, ScopeType::eSwitch}, scope->type)) {
+                        const bool inElse = scope->type == ScopeType::eElse;
+                        const bool inDoWhile = scope->type == ScopeType::eDo;
+                        const bool inLoop = contains({ScopeType::eDo, ScopeType::eFor, ScopeType::eWhile}, scope->type);
                         Token* condTok = getCondTokFromEnd(tok);
                         if (!condTok)
                             return Break();
                         if (!condTok->hasKnownIntValue() || inLoop) {
                             if (!analyzer->lowerToPossible())
                                 return Break(Analyzer::Terminate::Bail);
-                        } else if (condTok->values().front().intvalue == inElse) {
+                        } else if (condTok->getKnownIntValue() == inElse) {
                             return Break();
                         }
                         // Handle loop
@@ -648,10 +674,10 @@ namespace {
                         assert(!inDoWhile || Token::simpleMatch(tok, "} while ("));
                         if (Token::simpleMatch(tok, "} else {") || inDoWhile)
                             tok = tok->linkAt(2);
-                    } else if (contains({Scope::eTry, Scope::eCatch}, scope->type)) {
+                    } else if (contains({ScopeType::eTry, ScopeType::eCatch}, scope->type)) {
                         if (!analyzer->lowerToPossible())
                             return Break(Analyzer::Terminate::Bail);
-                    } else if (scope->type == Scope::eLambda) {
+                    } else if (scope->type == ScopeType::eLambda) {
                         return Break();
                     }
                 } else if (tok->isControlFlowKeyword() && Token::Match(tok, "if|while|for (") &&
