@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,17 +26,16 @@
 #include "standards.h"
 #include "symboldatabase.h"
 #include "token.h"
-#include "tokenlist.h"
 #include "valueflow.h"
+#include "vfvalue.h"
 
 #include "vf_settokenvalue.h"
 
-#include <cassert>
 #include <climits>
 #include <cstddef>
+#include <cstdint>
 #include <exception>
 #include <limits>
-#include <sstream>
 #include <utility>
 #include <vector>
 
@@ -47,7 +46,7 @@ namespace ValueFlow
         if (!vt || !vt->isIntegral() || vt->pointer)
             return false;
 
-        int bits;
+        std::uint8_t bits;
         switch (vt->type) {
         case ValueType::Type::BOOL:
             bits = 1;
@@ -97,19 +96,7 @@ namespace ValueFlow
         return true;
     }
 
-    bool getMinMaxValues(const std::string &typestr, const Settings &settings, bool cpp, MathLib::bigint &minvalue, MathLib::bigint &maxvalue)
-    {
-        TokenList typeTokens(&settings);
-        std::istringstream istr(typestr+";");
-        if (!typeTokens.createTokens(istr, cpp ? Standards::Language::CPP : Standards::Language::C))
-            return false;
-        typeTokens.simplifyPlatformTypes();
-        typeTokens.simplifyStdType();
-        const ValueType &vt = ValueType::parseDecl(typeTokens.front(), settings);
-        return getMinMaxValues(&vt, settings.platform, minvalue, maxvalue);
-    }
-
-    long long truncateIntValue(long long value, size_t value_size, const ValueType::Sign dst_sign)
+    MathLib::bigint truncateIntValue(MathLib::bigint value, size_t value_size, const ValueType::Sign dst_sign)
     {
         if (value_size == 0)
             return value;
@@ -127,7 +114,7 @@ namespace ValueFlow
     {
         const ValueType &valueType = ValueType::parseDecl(typeTok, settings);
 
-        return getSizeOf(valueType, settings);
+        return getSizeOf(valueType, settings, ValueFlow::Accuracy::ExactOrZero);
     }
 
     // Handle various constants..
@@ -135,9 +122,11 @@ namespace ValueFlow
     {
         if ((tok->isNumber() && MathLib::isInt(tok->str())) || (tok->tokType() == Token::eChar)) {
             try {
-                MathLib::bigint signedValue = MathLib::toBigNumber(tok->str());
+                MathLib::bigint signedValue = MathLib::toBigNumber(tok);
                 const ValueType* vt = tok->valueType();
-                if (vt && vt->sign == ValueType::UNSIGNED && signedValue < 0 && getSizeOf(*vt, settings) < sizeof(MathLib::bigint)) {
+                if (vt && vt->sign == ValueType::UNSIGNED && signedValue < 0
+                    && getSizeOf(*vt, settings, ValueFlow::Accuracy::ExactOrZero)
+                    < sizeof(MathLib::bigint)) {
                     MathLib::bigint minValue{}, maxValue{};
                     if (getMinMaxValues(tok->valueType(), settings.platform, minValue, maxValue))
                         signedValue += maxValue + 1;
@@ -152,7 +141,7 @@ namespace ValueFlow
         } else if (tok->isNumber() && MathLib::isFloat(tok->str())) {
             Value value;
             value.valueType = Value::ValueType::FLOAT;
-            value.floatValue = MathLib::toDoubleNumber(tok->str());
+            value.floatValue = MathLib::toDoubleNumber(tok);
             if (!tok->isTemplateArg())
                 value.setKnown();
             setTokenValue(tok, std::move(value), settings);
@@ -161,7 +150,7 @@ namespace ValueFlow
             if (!tok->isTemplateArg())
                 value.setKnown();
             setTokenValue(tok, std::move(value), settings);
-        } else if (tok->str() == "NULL" || (tok->isCpp() && tok->str() == "nullptr")) {
+        } else if (tok->str() == "NULL" || ((tok->isCpp() || settings.standards.c >= Standards::C23) && tok->str() == "nullptr")) {
             Value value(0);
             if (!tok->isTemplateArg())
                 value.setKnown();
@@ -171,7 +160,9 @@ namespace ValueFlow
                 (tok->next()->astOperand2()->valueType()->pointer == 0 || // <- TODO this is a bailout, abort when there are array->pointer conversions
                  (tok->next()->astOperand2()->variable() && !tok->next()->astOperand2()->variable()->isArray())) &&
                 !tok->next()->astOperand2()->valueType()->isEnum()) { // <- TODO this is a bailout, handle enum with non-int types
-                const size_t sz = getSizeOf(*tok->next()->astOperand2()->valueType(), settings);
+                const size_t sz = getSizeOf(*tok->next()->astOperand2()->valueType(),
+                                            settings,
+                                            ValueFlow::Accuracy::ExactOrZero);
                 if (sz) {
                     Value value(sz);
                     value.setKnown();
@@ -190,7 +181,8 @@ namespace ValueFlow
             }
             if (Token::simpleMatch(tok, "sizeof ( *")) {
                 const ValueType *vt = tok->tokAt(2)->valueType();
-                const size_t sz = vt ? getSizeOf(*vt, settings) : 0;
+                const size_t sz = vt ? getSizeOf(*vt, settings, ValueFlow::Accuracy::ExactOrZero)
+                                     : 0;
                 if (sz > 0) {
                     Value value(sz);
                     if (!tok2->isTemplateArg() && settings.platform.type != Platform::Type::Unspecified)
@@ -251,7 +243,9 @@ namespace ValueFlow
                         if (var->type()->classScope && var->type()->classScope->enumType)
                             size = getSizeOfType(var->type()->classScope->enumType, settings);
                     } else if (var->valueType()) {
-                        size = getSizeOf(*var->valueType(), settings);
+                        size = getSizeOf(*var->valueType(),
+                                         settings,
+                                         ValueFlow::Accuracy::ExactOrZero);
                     } else if (!var->type()) {
                         size = getSizeOfType(var->typeStartToken(), settings);
                     }
@@ -300,13 +294,13 @@ namespace ValueFlow
                 }
             } else if (!tok2->type()) {
                 const ValueType& vt = ValueType::parseDecl(tok2, settings);
-                size_t sz = getSizeOf(vt, settings);
+                size_t sz = getSizeOf(vt, settings, ValueFlow::Accuracy::ExactOrZero);
                 const Token* brac = tok2->astParent();
                 while (Token::simpleMatch(brac, "[")) {
                     const Token* num = brac->astOperand2();
                     if (num && ((num->isNumber() && MathLib::isInt(num->str())) || num->tokType() == Token::eChar)) {
                         try {
-                            const MathLib::biguint dim = MathLib::toBigUNumber(num->str());
+                            const MathLib::biguint dim = MathLib::toBigUNumber(num);
                             sz *= dim;
                             brac = brac->astParent();
                             continue;
@@ -350,7 +344,7 @@ namespace ValueFlow
         if (value.isFloatValue()) {
             value.valueType = Value::ValueType::INT;
             if (value.floatValue >= std::numeric_limits<int>::min() && value.floatValue <= std::numeric_limits<int>::max()) {
-                value.intvalue = value.floatValue;
+                value.intvalue = static_cast<MathLib::bigint>(value.floatValue);
             } else { // don't perform UB
                 value.intvalue = 0;
             }
@@ -397,16 +391,6 @@ namespace ValueFlow
         v.debugPath.emplace_back(tok, std::move(s));
     }
 
-    std::list<Value> getIteratorValues(std::list<Value> values, const Value::ValueKind* kind)
-    {
-        values.remove_if([&](const Value& v) {
-            if (kind && v.valueKind != *kind)
-                return true;
-            return !v.isIteratorValue();
-        });
-        return values;
-    }
-
     MathLib::bigint valueFlowGetStrLength(const Token* tok)
     {
         if (tok->tokType() == Token::eString)
@@ -421,61 +405,4 @@ namespace ValueFlow
         }
         return 0;
     }
-
-    bool isBreakOrContinueScope(const Token* endToken)
-    {
-        if (!Token::simpleMatch(endToken, "}"))
-            return false;
-        return Token::Match(endToken->tokAt(-2), "break|continue ;");
-    }
-
-    const Scope* getLoopScope(const Token* tok)
-    {
-        if (!tok)
-            return nullptr;
-        const Scope* scope = tok->scope();
-        while (scope && scope->type != Scope::eWhile && scope->type != Scope::eFor && scope->type != Scope::eDo)
-            scope = scope->nestedIn;
-        return scope;
-    }
-
-    void setSymbolic(Value& value, const Token* tok)
-    {
-        assert(tok && tok->exprId() > 0 && "Missing expr id for symbolic value");
-        value.valueType = Value::ValueType::SYMBOLIC;
-        value.tokvalue = tok;
-    }
-
-    Value makeSymbolic(const Token* tok, MathLib::bigint delta)
-    {
-        Value value;
-        value.setKnown();
-        setSymbolic(value, tok);
-        value.intvalue = delta;
-        return value;
-    }
-
-    void removeImpossible(std::list<Value>& values, int indirect)
-    {
-        values.remove_if([&](const Value& v) {
-            if (indirect >= 0 && v.indirect != indirect)
-                return false;
-            return v.isImpossible();
-        });
-    }
-
-    void changeKnownToPossible(std::list<Value> &values, int indirect)
-    {
-        for (Value& v: values) {
-            if (indirect >= 0 && v.indirect != indirect)
-                continue;
-            v.changeKnownToPossible();
-        }
-    }
-
-    void lowerToPossible(std::list<Value>& values, int indirect)
-    {
-        changeKnownToPossible(values, indirect);
-        removeImpossible(values, indirect);
-    }
 }
